@@ -2,7 +2,7 @@ from pylabel.analyze import Analyze
 from pylabel.exporter import Export
 from pylabel.visualize import Visualize
 
-from pylabel.splitter import GroupShuffleSplit
+from pylabel.splitter import GroupShuffleSplit, test
 from pylabel.splitter import StratifiedGroupShuffleSplit
 
 
@@ -10,12 +10,12 @@ class Dataset:
     def __init__(self, df):
         self.df = df
         self.name = "dataset"
-        self.path_to_annotations = ""
-        self.analyze = Analyze(self.df) 
+        self.path_to_annotations = ""    
         self.GroupShuffleSplit = GroupShuffleSplit
+        self.test = test
         self.StratifiedGroupShuffleSplit = StratifiedGroupShuffleSplit
-        self.export = Export()
-        self.visualize = Visualize()
-
-    
+        self.export = Export(dataset=self)
+        self.visualize = Visualize(dataset=self)
+        self.analyze = Analyze(self)
+        #self.splitter = Splitter(dataset=self)
 
